@@ -12,6 +12,7 @@
 
 #include <KColorScheme>
 #include <KConfigGroup>
+#include <KConfigWatcher>
 #include <KPluginMetaData>
 #include <KSvg/ImageSet>
 
@@ -33,14 +34,6 @@ class Theme;
 static const int DEFAULT_WALLPAPER_WIDTH = 1920;
 static const int DEFAULT_WALLPAPER_HEIGHT = 1200;
 
-enum CacheType {
-    NoCache = 0,
-    PixmapCache = 1,
-    SvgElementsCache = 2,
-};
-Q_DECLARE_FLAGS(CacheTypes, CacheType)
-Q_DECLARE_OPERATORS_FOR_FLAGS(CacheTypes)
-
 class ThemePrivate : public QObject, public QSharedData
 {
     Q_OBJECT
@@ -52,9 +45,8 @@ public:
     KConfigGroup &config();
 
     QString imagePath(const QString &theme, const QString &type, const QString &image);
-    QString findInTheme(const QString &image, const QString &theme, bool cache = true);
-    void discardCache(CacheTypes caches);
-    void scheduleThemeChangeNotification(CacheTypes caches);
+    QString findInTheme(const QString &image, const QString &theme);
+    void scheduleThemeChangeNotification();
     void setThemeName(const QString &themeName, bool writeSettings, bool emitChanged);
     void processWallpaperSettings(const KSharedConfigPtr &metadata);
     void processContrastSettings(const KSharedConfigPtr &metadata);
@@ -63,11 +55,10 @@ public:
 
     QColor color(Theme::ColorRole role, Theme::ColorGroup group = Theme::NormalColorGroup) const;
 
-    void updateKSvgSelectors(CacheTypes notify);
+    void updateKSvgSelectors();
 
 public Q_SLOTS:
     void colorsChanged();
-    void settingsFileChanged(const QString &settings);
     void notifyOfChanged();
     void settingsChanged(bool emitChanges);
 
@@ -79,8 +70,6 @@ Q_SIGNALS:
 
 public:
     static const char defaultTheme[];
-    static const char systemColorsTheme[];
-    static const char themeRcFile[];
 
     static ContrastEffectWatcher *s_backgroundContrastEffectWatcher;
 
@@ -103,17 +92,13 @@ public:
     QPalette palette;
     bool eventFilter(QObject *watched, QEvent *event) override;
     KConfigGroup cfg;
+    KConfigWatcher::Ptr plasmaRcWatcher;
     QString defaultWallpaperTheme;
     QString defaultWallpaperSuffix;
     int defaultWallpaperWidth;
     int defaultWallpaperHeight;
-    QHash<QString, QString> discoveries;
     QTimer *selectorsUpdateTimer;
     QTimer *updateNotificationTimer;
-    unsigned cacheSize;
-    CacheTypes cachesToDiscard;
-    QString themeVersion;
-    QString themeMetadataPath;
 
     bool compositingActive : 1;
     bool backgroundContrastActive : 1;
